/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IFluidHandle, IFluidHandleContext, IRequest, IResponse } from "@fluidframework/core-interfaces";
/**
 * This handle is used to dynamically load a Fluid object on a remote client and is created on parsing a serialized
 * FluidObjectHandle.
 * This class is used to generate an IFluidHandle when de-serializing any all handles (including handles to DDSs, custom
 * objects) that are stored in SharedObjects. The Data Store or SharedObject corresponding to the IFluidHandle can be
 * retrieved by calling `get` on it.
 */
export declare class RemoteFluidObjectHandle implements IFluidHandle {
    readonly absolutePath: string;
    readonly routeContext: IFluidHandleContext;
    get IFluidRouter(): this;
    get IFluidHandleContext(): this;
    get IFluidHandle(): this;
    readonly isAttached = true;
    private objectP;
    /**
     * Creates a new RemoteFluidObjectHandle when parsing an IFluidHandle.
     * @param absolutePath - The absolute path to the handle from the container runtime.
     * @param routeContext - The root IFluidHandleContext that has a route to this handle.
     */
    constructor(absolutePath: string, routeContext: IFluidHandleContext);
    get(): Promise<any>;
    attachGraph(): void;
    bind(handle: IFluidHandle): void;
    request(request: IRequest): Promise<IResponse>;
}
//# sourceMappingURL=remoteObjectHandle.d.ts.map