/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IFluidHandle, IFluidHandleContext } from "@fluidframework/core-interfaces";
/**
 * JSON serialized form of an IFluidHandle
 */
export interface ISerializedHandle {
    type: "__fluid_handle__";
    url: string;
}
export declare const isSerializedHandle: (value: any) => value is ISerializedHandle;
export interface IFluidSerializer {
    /**
     * Given a mostly-plain object that may have handle objects embedded within, will return a fully-plain object
     * where any embedded IFluidHandles have been replaced with a serializable form.
     *
     * The original `input` object is not mutated.  This method will shallowly clones all objects in the path from
     * the root to any replaced handles.  (If no handles are found, returns the original object.)
     */
    encode(value: any, bind: IFluidHandle): any;
    /**
     * Given a fully-jsonable object tree that may have encoded handle objects embedded within, will return an
     * equivalent object tree where any encoded IFluidHandles have been replaced with their decoded form.
     *
     * The original `input` object is not mutated.  This method will shallowly clone all objects in the path from
     * the root to any replaced handles.  (If no handles are found, returns the original object.)
     *
     * The decoded handles are implicitly bound to the handle context of this serializer.
     */
    decode(input: any): any;
    /**
     * Stringifies a given value. Converts any IFluidHandle to its stringified equivalent.
     */
    stringify(value: any, bind: IFluidHandle): string;
    /**
     * Parses the given JSON input string and returns the JavaScript object defined by it. Any Fluid
     * handles will be realized as part of the parse
     */
    parse(value: string): any;
}
/**
 * Data Store serializer implementation
 */
export declare class FluidSerializer implements IFluidSerializer {
    private readonly context;
    private readonly handleParsedCb;
    private readonly root;
    constructor(context: IFluidHandleContext, handleParsedCb: (handle: IFluidHandle) => void);
    get IFluidSerializer(): this;
    /**
     * Given a mostly-jsonable object tree that may have handle objects embedded within, will return a
     * fully-jsonable object tree where any embedded IFluidHandles have been replaced with a serializable form.
     *
     * The original `input` object is not mutated.  This method will shallowly clone all objects in the path from
     * the root to any replaced handles.  (If no handles are found, returns the original object.)
     *
     * Any unbound handles encountered are bound to the provided IFluidHandle.
     */
    encode(input: any, bind: IFluidHandle): any;
    /**
     * Given a fully-jsonable object tree that may have encoded handle objects embedded within, will return an
     * equivalent object tree where any encoded IFluidHandles have been replaced with their decoded form.
     *
     * The original `input` object is not mutated.  This method will shallowly clone all objects in the path from
     * the root to any replaced handles.  (If no handles are found, returns the original object.)
     *
     * The decoded handles are implicitly bound to the handle context of this serializer.
     */
    decode(input: any): any;
    stringify(input: any, bind: IFluidHandle): string;
    parse(input: string): any;
    private readonly encodeValue;
    private readonly decodeValue;
    private recursivelyReplace;
    protected serializeHandle(handle: IFluidHandle, bind: IFluidHandle): {
        type: string;
        url: string;
    };
}
//# sourceMappingURL=serializer.d.ts.map